function Player(xIn, yIn, levelIn)
{
	this.x = xIn;
	this.y = yIn;
	this.speed = 4;
	this.direction = new Point(0,0);
	this.level = levelIn;
	this.collisionRect = new Rectangle(xIn, yIn, 10, 10);
    this.canvas = document.getElementById('canvas');
	this.health = 100;
	
	var keysDown = {};

	addEventListener("keydown", function (e) {
		keysDown[e.keyCode] = true;
	}, false);

	addEventListener("keyup", function (e) {
		delete keysDown[e.keyCode];
	}, false);
	
	this.update = function()
	{
		if (this.health <= 0)
		{
			this.level.playerDead = true;
		}
	
		// Update input
		if (87 in keysDown)
		{
			this.direction.y = -1;
		}
		else if (83 in keysDown)
		{
			this.direction.y = 1;
		}
		else
		{
			this.direction.y = 0;
		}
		
		if (65 in keysDown)
		{
			this.direction.x = -1;
		}
		else if (68 in keysDown)
		{
			this.direction.x = 1;
		}
		else
		{
			this.direction.x = 0;
		}
		
		this.moveBy = this.direction.normalize(this.speed);
		
		if (this.x + this.moveBy.x < 0)
		{
			this.direction.x = 0;
		}
		if (this.y + this.moveBy.y >= this.canvas.height - this.collisionRect.h || this.y + this.moveBy.y < 0)
		{
			this.direction.y = 0;
		}
		
		this.moveBy = this.direction.normalize(this.speed);
		
		// Update collision/bounds
		for (var x = 0; x < level.verticalSpawners.length; x++)
		{
			s = level.verticalSpawners[x];
			b = s.currentBlock;
			// console.log(level.verticalSpawners.currentBlock.rect.w);
			
			if (this.direction.x != 0 && this.y <= b.y + b.rect.h && this.y >= b.y)
			{
				if (b.collide(new Rectangle(this.x + this.moveBy.x, this.y, this.collisionRect.w, this.collisionRect.h)))
				{
					this.moveBy.x = 0;
					
					if (b.canHitPlayer)
					{
						this.health -= b.damage;
						b.canHitPlayer = false;
					}
				}
			}
			
			if (this.direction.y != 0 && this.x <= b.x + b.rect.w && this.x >= b.x)
			{
				if (b.collide(new Rectangle(this.x, this.y + this.moveBy.y, this.collisionRect.w, this.collisionRect.h)))
				{
					this.moveBy.y = 0;
					
					if (b.canHitPlayer)
					{
						this.health -= b.damage;
						b.canHitPlayer = false;
					}
				}
			}
		}
		
		for (var y = 0; y < level.horizontalSpawners.length; y++)
		{
			s = level.horizontalSpawners[y];
			b = s.currentBlock;
			
			if (this.direction.x != 0 && this.y <= b.y + b.rect.h && this.y >= b.y)
			{
				if (b.collide(new Rectangle(this.x + this.moveBy.x, this.y, this.collisionRect.w, this.collisionRect.h)))
				{
					this.moveBy.x = 0;
					
					if (b.canHitPlayer)
					{
						this.health -= b.damage;
						b.canHitPlayer = false;
					}
				}
			}
			if (this.direction.y != 0 && this.x <= b.x + b.rect.w && this.x >= b.x)
			{
				if (b.collide(new Rectangle(this.x, this.y + this.moveBy.y, this.collisionRect.w, this.collisionRect.h)))
				{
					this.moveBy.y = 0;
					
					if (b.canHitPlayer)
					{
						this.health -= b.damage;
						b.canHitPlayer = false;
					}
				}
			}
		}
			
		// Apply movement
		this.x += this.moveBy.x;
		this.y += this.moveBy.y;
		this.collisionRect.x = this.x;
		this.collisionRect.y = this.y;
		
		if (this.x + this.moveBy.x >= this.canvas.width - this.collisionRect.w)
		{
			this.level.completed = true;
		}
	}
	
	this.draw = function(ctx)
	{
		ctx.fillStyle = "#FFFFFF";
		ctx.fillRect(this.x, this.y, 10, 10);
		
		ctx.fillStyle = "#FFFFFF";
		ctx.font="20px Verdana";
		ctx.textAlign="left";
		ctx.fillText("Health: " + this.health,10,30);
	}
}